==> haskell-hasql-dynamic-statements-0.3.1.1-270.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-dynamic-statements.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-dynamic-statements
version:              0.3.1.1
visibility:           public
id:                   hasql-dynamic-statements-0.3.1.1-3KxL6xXFafg5OkAOOAtHCk
key:                  hasql-dynamic-statements-0.3.1.1-3KxL6xXFafg5OkAOOAtHCk
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-dynamic-statements
synopsis:             Toolkit for constructing Hasql statements dynamically
description:
    This library introduces into the Hasql ecosystem a new abstraction named Snippet,
    which makes it trivial to construct SQL, while injecting values.
    It is intended to be used when the SQL of your statement depends on the parameters,
    that you want to pass in.

abi:                  6d039a809e5111b5525337d94e227e31
exposed:              True
exposed-modules:
    Hasql.DynamicStatements.Session Hasql.DynamicStatements.Snippet
    Hasql.DynamicStatements.Statement

hidden-modules:
    Hasql.DynamicStatements.Prelude
    Hasql.DynamicStatements.Snippet.Defs

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hasql-dynamic-statements-0.3.1.1

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hasql-dynamic-statements-0.3.1.1

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hasql-dynamic-statements-0.3.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-dynamic-statements
hs-libraries:         HShasql-dynamic-statements-0.3.1.1-3KxL6xXFafg5OkAOOAtHCk
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    hasql-1.5.0.5-D13dwG1Hnoj5UOBosN4Mcc
    hasql-implicits-0.1.0.5-F43A5NZxKrpIJ9zVJhuqDQ
    ptr-0.16.8.7-L0jN3nXgiI8CXCoCBTc7ze

haddock-interfaces:
    /usr/share/doc/haskell-hasql-dynamic-statements/html/hasql-dynamic-statements.haddock

haddock-html:         /usr/share/doc/haskell-hasql-dynamic-statements/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-dynamic-statements-0.3.1.1-271-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-dynamic-statements.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-dynamic-statements
version:              0.3.1.1
visibility:           public
id:                   hasql-dynamic-statements-0.3.1.1-FAKaH6psqzZE4bEbLNsnz1
key:                  hasql-dynamic-statements-0.3.1.1-FAKaH6psqzZE4bEbLNsnz1
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-dynamic-statements
synopsis:             Toolkit for constructing Hasql statements dynamically
description:
    This library introduces into the Hasql ecosystem a new abstraction named Snippet,
    which makes it trivial to construct SQL, while injecting values.
    It is intended to be used when the SQL of your statement depends on the parameters,
    that you want to pass in.

abi:                  9da32f5d0f743a2819a5c07102863fee
exposed:              True
exposed-modules:
    Hasql.DynamicStatements.Session Hasql.DynamicStatements.Snippet
    Hasql.DynamicStatements.Statement

hidden-modules:
    Hasql.DynamicStatements.Prelude
    Hasql.DynamicStatements.Snippet.Defs

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hasql-dynamic-statements-0.3.1.1

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hasql-dynamic-statements-0.3.1.1

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hasql-dynamic-statements-0.3.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-dynamic-statements
hs-libraries:         HShasql-dynamic-statements-0.3.1.1-FAKaH6psqzZE4bEbLNsnz1
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    hasql-1.5.0.5-D56QxJSATLi7EO6Br9LDFG
    hasql-implicits-0.1.0.5-AmBtfOzperTDwrZn3KQZ75
    ptr-0.16.8.7-DnBX4kqQ09cIxCUhB1J36g

haddock-interfaces:
    /usr/share/doc/haskell-hasql-dynamic-statements/html/hasql-dynamic-statements.haddock

haddock-html:         /usr/share/doc/haskell-hasql-dynamic-statements/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
